@@ -79,7 +79,7 @@ from typing import TYPE_CHECKING, Any, Callable, Sequence, Type
 from griffe.collections import LinesCollection
 from griffe.exceptions import LastNodeError, RootNodeError
 from griffe.expressions import Expression, Name
-from griffe.logger import get_logger
+from griffe.logger import LogLevel, get_logger
 
 logger = get_logger(__name__)
 
@@ -327,8 +327,6 @@ class ObjectNode:
             return ObjectKind.STATICMETHOD
         if self.is_classmethod:
             return ObjectKind.CLASSMETHOD
-        if self.is_method_descriptor:
-            return ObjectKind.METHOD_DESCRIPTOR
         if self.is_method:
             return ObjectKind.METHOD
         if self.is_builtin_method:
@@ -343,6 +341,8 @@ class ObjectNode:
             return ObjectKind.CACHED_PROPERTY
         if self.is_property:
             return ObjectKind.PROPERTY
+        if self.is_method_descriptor:
+            return ObjectKind.METHOD_DESCRIPTOR
         return ObjectKind.ATTRIBUTE
 
     @cached_property
@@ -778,12 +778,17 @@ def get_annotation(node: AST | None, parent: Module | Class) -> str | Name | Exp
     return _get_annotation(node, parent)
 
 
-def safe_get_annotation(node: AST | None, parent: Module | Class) -> str | Name | Expression | None:
+def safe_get_annotation(
+    node: AST | None,
+    parent: Module | Class,
+    log_level: LogLevel = LogLevel.error,
+) -> str | Name | Expression | None:
     """Safely (no exception) extract a resolvable annotation.
 
     Parameters:
         node: The annotation node.
         parent: The parent used to resolve the name.
+        log_level: Log level to use to log a message.
 
     Returns:
         A string or resovable name or expression.
@@ -796,7 +801,7 @@ def safe_get_annotation(node: AST | None, parent: Module | Class) -> str | Name
             message += f" at {parent.relative_filepath}:{node.lineno}"  # type: ignore[union-attr]
         if not isinstance(error, KeyError):
             message += f": {error}"
-        logger.error(message)
+        getattr(logger, log_level.value)(message)
         return None
 
 
@@ -825,7 +830,14 @@ def get_docstring(
     if isinstance(doc, NodeConstant) and isinstance(doc.value, str):
         return doc.value, doc.lineno, doc.end_lineno  # type: ignore[attr-defined]
     if isinstance(doc, NodeStr):
-        return doc.s, doc.lineno, doc.end_lineno  # type: ignore[attr-defined]
+        # TODO: remove once Python 3.7 support is dropped
+        # on Python 3.7, lineno seems to be the ending line of the string
+        # rather than the starting one, so we substract the number of newlines
+        lineno = doc.lineno
+        if sys.version_info < (3, 8):
+            lineno -= doc.s.count("\n")
+
+        return doc.s, lineno, doc.end_lineno  # type: ignore[attr-defined]
     return None, None, None
 
 
@@ -1081,8 +1093,8 @@ def _get_sub_value(node: NodeSub) -> str:
 
 def _get_subscript_value(node: NodeSubscript) -> str:
     subscript = _get_value(node.slice)
-    if isinstance(subscript, str):
-        subscript = subscript.strip("()")
+    if isinstance(subscript, str) and subscript.startswith("(") and subscript.endswith(")"):
+        subscript = subscript[1:-1]
     return f"{_get_value(node.value)}[{subscript}]"
 
 
