@@ -57,9 +57,11 @@ stdlib_decorators = {
     "abc.abstractmethod": {"abstractmethod"},
     "functools.cache": {"cached"},
     "functools.cached_property": {"cached", "property"},
+    "cached_property.cached_property": {"cached", "property"},
     "functools.lru_cache": {"cached"},
     "dataclasses.dataclass": {"dataclass"},
 }
+typing_overload = {"typing.overload", "typing_extensions.overload"}
 
 
 def visit(
@@ -319,9 +321,9 @@ class Visitor(BaseVisitor):  # noqa: WPS338
             for decorator_node in node.decorator_list:
                 decorator_value = safe_get_value(decorator_node, self.filepath)
                 overload = (
-                    decorator_value == "typing.overload"
+                    decorator_value in typing_overload
                     or decorator_value == "overload"
-                    and self.current.resolve("overload") == "typing.overload"
+                    and self.current.resolve("overload") in typing_overload
                 )
                 decorators.append(
                     Decorator(
@@ -334,6 +336,21 @@ class Visitor(BaseVisitor):  # noqa: WPS338
             lineno = node.lineno
 
         labels |= self.decorators_to_labels(decorators)
+
+        if "property" in labels:
+            attribute = Attribute(
+                name=node.name,
+                value=None,
+                annotation=safe_get_annotation(node.returns, parent=self.current),
+                lineno=node.lineno,
+                endlineno=node.end_lineno,  # type: ignore[union-attr]
+                docstring=self._get_docstring(node),
+                runtime=not self.type_guarded,
+            )
+            attribute.labels |= labels
+            self.current[node.name] = attribute
+            return
+
         base_property, property_function = self.get_base_property(decorators)
 
         # handle parameters
@@ -377,7 +394,7 @@ class Visitor(BaseVisitor):  # noqa: WPS338
             annotation = safe_get_annotation(node.args.vararg.annotation, parent=self.current)
             parameters.add(
                 Parameter(
-                    f"*{node.args.vararg.arg}",
+                    node.args.vararg.arg,
                     annotation=annotation,
                     kind=ParameterKind.var_positional,
                     default="()",
@@ -407,7 +424,7 @@ class Visitor(BaseVisitor):  # noqa: WPS338
             annotation = safe_get_annotation(node.args.kwarg.annotation, parent=self.current)
             parameters.add(
                 Parameter(
-                    f"**{node.args.kwarg.arg}",
+                    node.args.kwarg.arg,
                     annotation=annotation,
                     kind=ParameterKind.var_keyword,
                     default="{}",  # noqa: P103
@@ -610,7 +627,7 @@ class Visitor(BaseVisitor):  # noqa: WPS338
         """
         with suppress(AttributeError):
             all_augment = (
-                node.target.id == "__all__"  # type: ignore[attr-defined]
+                node.target.id == "__all__"  # type: ignore[attr-defined,union-attr]
                 and self.current.is_module
                 and isinstance(node.op, ast.Add)
             )
