@@ -109,15 +109,15 @@ def _read_block_items(docstring: Docstring, offset: int) -> ItemsBlock:  # noqa:
                 f"should be {indent} * 2 = {indent*2} spaces, not {cont_indent}",
             )
 
+        elif _is_empty_line(line):
+            # empty line: preserve it in the current item
+            current_item[1].append("")
+
         elif line.startswith(indent * " "):
             # indent equal to initial one: new item
             items.append(current_item)
             current_item = (new_offset, [line[indent:]])
 
-        elif _is_empty_line(line):
-            # empty line: preserve it in the current item
-            current_item[1].append("")
-
         else:
             # indent lower than initial one: end of section
             break
@@ -172,8 +172,7 @@ def _read_parameters(  # noqa: WPS231
     block, new_offset = _read_block_items(docstring, offset)
 
     for line_number, param_lines in block:
-
-        # check the presence of a name and description, separated by a semi-colon
+        # check the presence of a name and description, separated by a colon
         try:
             name_with_type, description = param_lines[0].split(":", 1)
         except ValueError:
@@ -363,7 +362,12 @@ def _read_returns_section(  # noqa: WPS231
         else:
             # try to retrieve the annotation from the docstring parent
             with suppress(AttributeError, KeyError, ValueError):
-                annotation = docstring.parent.returns  # type: ignore[union-attr]
+                if docstring.parent.is_function:  # type: ignore[union-attr]
+                    annotation = docstring.parent.returns  # type: ignore[union-attr]
+                elif docstring.parent.is_attribute:  # type: ignore[union-attr]
+                    annotation = docstring.parent.annotation  # type: ignore[union-attr]
+                else:
+                    raise ValueError
                 if len(block) > 1:
                     if annotation.is_tuple:
                         annotation = annotation.tuple_item(index)
